summaryrefslogtreecommitdiffstats
path: root/chrome/browser/browser.h
diff options
context:
space:
mode:
Diffstat (limited to 'chrome/browser/browser.h')
-rw-r--r--chrome/browser/browser.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/chrome/browser/browser.h b/chrome/browser/browser.h
index 98464b3..2dd56b1 100644
--- a/chrome/browser/browser.h
+++ b/chrome/browser/browser.h
@@ -162,8 +162,8 @@ class Browser : public TabStripModelDelegate,
// Gets the FavIcon of the page in the selected tab.
SkBitmap GetCurrentPageIcon() const;
- // Gets the title of the page in the selected tab.
- string16 GetCurrentPageTitle() const;
+ // Gets the title of the window based on the selected tab's title.
+ string16 GetWindowTitleForCurrentTab() const;
// Prepares a title string for display (removes embedded newlines, etc).
static void FormatTitleForDisplay(string16* title);